@@ -46,7 +46,7 @@
 
 fan.sphere <- function (angle = 1, method = c("regular","random"),
                         origin = c(0,0,0),
-                        ref.pseudo = "", 
+                        ref.pseudo = "ref1", 
                         frame.of.reference = "",
                         alias = "", 
                         description = "spherical fan"){
